==> tecfy_corev2_package-1.1.35.tar.gz: lib/models/entity/property_multi_dropdown.model.dart <==
part of tecfy_corev2_client_package;

class PropertyMultiDropdown extends Property {
  late String entityName;

  Property? entityDisplayProp;

  /// <summary>
  /// used to get the list using custom EndPoint like "Item/GetItemInfo?brand={brandId}&model={modelId}&category={itemCategoryId}&year={year}"
  /// </summary>
  late String dropdownUrl;

  late bool isFilter;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  late String filterField;
  late String filterQuery;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  late String filterValueField;

  List<Map<String, String>>? options;

  /// <summary>
  /// Fileds that in main entity and dropdown entity with the same name, that you need to update the value of the main entity with the value in dropdown entity
  /// For example: when select item the UOM_ID of the invoice will be overwrten
  /// Can add multi properties seperated by comma
  /// </summary>
  Map<String, String>? overwritePropertiesOnSelect;

  PropertyMultiDropdown(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      required this.entityName,
      this.overwritePropertiesOnSelect,
      this.isFilter = false,
      this.filterField = '',
      this.filterQuery = '',
      this.filterValueField = ''})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Dropdown,
            valueType: ValueTypes.Text,
            isRequired: isRequired) {
    dropdownUrl = '';
    bindOptions();
  }

  PropertyMultiDropdown.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    entityName = row['entityName'] ?? '';
    dropdownUrl = row['dropdownUrl'] ?? '';
    isFilter = row['isFilter'] ?? false;
    filterField = lowerFirst(row['filterField'] ?? '') ?? '';
    filterQuery = row['filterQuery'] ?? '';

    overwritePropertiesOnSelect = {};

    if (row['overwritePropertiesOnSelect'] != null) {
      for (var k in row['overwritePropertiesOnSelect'].toString().split(',')) {
        var s = k.split(':');
        overwritePropertiesOnSelect![lowerFirst(s.first)!] =
            lowerFirst(s.last)!;
      }
    }

    dbName = lowerFirst(row['dbName']) ?? '';

    filterValueField = lowerFirst(row['filterValueField'] ?? '') ?? '';
    if (entityName.isEmpty && filterValueField.isNotEmpty) {
      filterValueField = row['filterValueField'];
    }
    bindOptions();
  }

  void bindOptions() {
    if (entityName.isEmpty && filterValueField.isNotEmpty) {
      options = filterValueField.split(',').map<Map<String, String>>((e) {
        var s = e.split(':');
        return {
          'id': s.first,
          'nameEn': s.first,
          'nameAr': s.last,
        };
      }).toList();
    }
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    // return data[dbName]?.toString() ?? '';
    return MapService.getValue(data, dbName);
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null &&
        MapService.getValue(data, dbName).toString().isNotEmpty) return false;
    if (defaultString?.isNotEmpty ?? false) {
      // data[dbName] = defaultString;
      MapService.updateValue(data, dbName, defaultString);
      return true;
    }
    return false;
  }
}

==> tecfy_corev2_package-1.1.66.tar.gz: lib/models/entity/property_multi_dropdown.model.dart <==
part of tecfy_corev2_client_package;

class PropertyMultiDropdown extends Property {
  late String entityName;

  Property? entityDisplayProp;

  /// <summary>
  /// used to get the list using custom EndPoint like "Item/GetItemInfo?brand={brandId}&model={modelId}&category={itemCategoryId}&year={year}"
  /// </summary>
  late String dropdownUrl;

  late bool isFilter;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  late String filterField;
  late String filterQuery;

  /// <summary>
  /// where value of FilterField is null of embty then the value of FilterValueField must refer to Array proerty of same dropdwn Entity
  /// </summary>
  late String filterValueField;

  List<Map<String, String>>? options;

  /// <summary>
  /// Fileds that in main entity and dropdown entity with the same name, that you need to update the value of the main entity with the value in dropdown entity
  /// For example: when select item the UOM_ID of the invoice will be overwrten
  /// Can add multi properties seperated by comma
  /// </summary>
  Map<String, String>? overwritePropertiesOnSelect;

  PropertyMultiDropdown(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      required this.entityName,
      this.overwritePropertiesOnSelect,
      this.isFilter = false,
      this.filterField = '',
      this.filterQuery = '',
      this.filterValueField = ''})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Dropdown,
            valueType: ValueTypes.Text,
            isRequired: isRequired) {
    dropdownUrl = '';
    bindOptions();
  }

  PropertyMultiDropdown.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    entityName = row['entityName'] ?? '';
    dropdownUrl = row['dropdownUrl'] ?? '';
    isFilter = row['isFilter'] ?? false;
    filterField = lowerFirst(row['filterField'] ?? '') ?? '';
    filterQuery = row['filterQuery'] ?? '';

    overwritePropertiesOnSelect = {};

    if (row['overwritePropertiesOnSelect'] != null) {
      for (var k in row['overwritePropertiesOnSelect'].toString().split(',')) {
        var s = k.split(':');
        overwritePropertiesOnSelect![lowerFirst(s.first)!] =
            lowerFirst(s.last)!;
      }
    }

    dbName = lowerFirst(row['dbName']) ?? '';

    filterValueField = lowerFirst(row['filterValueField'] ?? '') ?? '';
    if (entityName.isEmpty && filterValueField.isNotEmpty) {
      filterValueField = row['filterValueField'];
    }
    bindOptions();
  }

  void bindOptions() {
    if (entityName.isEmpty && filterValueField.isNotEmpty) {
      options = filterValueField.split(',').map<Map<String, String>>((e) {
        var s = e.split(':');
        return {
          'id': s.first,
          'nameEn': s.first,
          'nameAr': s.last,
        };
      }).toList();
    }
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    // return data[dbName]?.toString() ?? '';
    return MapService.getValue(data, dbName).toString();
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null &&
        MapService.getValue(data, dbName).toString().isNotEmpty) return false;
    if (defaultString?.isNotEmpty ?? false) {
      // data[dbName] = defaultString;
      MapService.updateValue(data, dbName, defaultString);
      return true;
    }
    return false;
  }
}
